Under the Health Insurance Portability and Accountability Act (HIPAA),
Protected Health Information includes any part of the patient\'s medical
record of payment history.

PHI that is linked based on the following list of 18 identifiers must be
treated with special care:

* Names
* All geographical identifiers smaller than a state, except for the
  initial three digits of a zip code if, according to the current
  publicly available data from the U.S. Bureau of the Census: the
  geographic unit formed by combining all zip codes with the same
  three initial digits contains more than 20,000 people; and the
  initial three digits of a zip code for all such geographic units
  containing 20,000 or fewer people is changed to 000
* Dates (other than year) directly related to an individual
* Phone Numbers
* Fax numbers
* Email addresses
* Social Security numbers
* Medical record numbers
* Health insurance beneficiary numbers
* Account numbers
* Certificate/license numbers
* Vehicle identifiers and serial numbers, including license plate
  numbers
* Device identifiers and serial numbers
* Web Uniform Resource Locators (URLs)
* Internet Protocol (IP) address numbers
* Biometric identifiers, including finger, retinal and voice prints
* Full face photographic images and any comparable images
* Any other unique identifying number, characteristic, or code except
  the unique code assigned by the investigator to code the data
